
# Slot: domain


defines the type of the subject of the slot.  Given the following slot definition
  S1:
    domain: C1
    range:  C2
the declaration
  X:
    S1: Y

implicitly asserts that X is an instance of C1

URI: [linkml:domain](https://w3id.org/linkml/domain)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [ClassDefinition](ClassDefinition.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
